@@ -39,8 +39,6 @@ class TextChannel(tp.ChannelTypeText):
 			self.__callback
 		)
 
-		self._filter_out_reported = gvoice.conversations.FilterOutReported()
-
 		# The only reason there should be anything in the conversation is if
 		# its new, so report it all
 		try:
@@ -138,17 +136,6 @@ class TextChannel(tp.ChannelTypeText):
 			)
 			return
 
-		newConversations = self._filter_out_reported(newConversations)
-		newConversations = list(newConversations)
-		postReportedLen = len(newConversations)
-		if postReportedLen < postSelfLen:
-			self._conn.log_to_user(__name__, "Dropped %s messages due to already being reported" % (postSelfLen - postReportedLen))
-		if not newConversations:
-			_moduleLogger.debug(
-				"New messages for %r have already been reported" % (self._contactKey, )
-			)
-			return
-
 		newConversations = gvoice.conversations.filter_out_read(newConversations)
 		newConversations = list(newConversations)
 		postReadLen = len(newConversations)
